<?php

namespace Drupal\cards\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;
use Drupal\Core\TypedData\MapDataDefinition;
use Drupal\entityreference_view_mode\Plugin\Field\FieldType\EntityReferenceViewMode;

/**
 * Plugin implementation of the 'field_content_view' field type.
 *
 * @FieldType(
 *   id = "card_view",
 *   label = @Translation("Cards"),
 *   module = "cards",
 *   description = @Translation("Field referencing a piece of content and an associated view mode."),
 *   default_widget = "card_view_widget",
 *   default_formatter = "card_view_formatter"
 * )
 */
class CardView extends EntityReferenceViewMode {

    use CardViewTrait;

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return [
      'target_type' => 'node',
      'bundles' => [],
      'view_modes' => [],
      'widths' => [],
      'colors' => [],
      'heights' => [],
      'icons' => [],
      'classes' => [],
    ];
  }

    public function fieldSettingsForm(array $form, FormStateInterface $form_state) {

        $element = parent::fieldSettingsForm($form, $form_state);



        $element += $this->addCardFieldSettingsForm($form, $form_state);

        return $element;
    }


    public static function schema(FieldStorageDefinitionInterface $field_definition) {

        $schema = parent::schema($field_definition);


        $cards_schema = CardView::addCardschema($field_definition);

        $schema['columns'] += $cards_schema['columns'];

        return $schema;

    }

    public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition)
    {

            $properties = parent::propertyDefinitions($field_definition);

        $properties += CardView::addCardpropertyDefinitions($field_definition);
        return $properties;

    }

}
