<?php

namespace Drupal\cards\Plugin\Field\FieldWidget;


use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\entityreference_view_mode\Plugin\Field\FieldWidget\EntityReferenceViewModeWidget;

/**
 * Plugin implementation of the 'field_example_text' widget.
 *
 * @FieldWidget(
 *   id = "card_children_view_widget",
 *   module = "cards",
 *   label = @Translation("Card Children Widget"),
 *   field_types = {
 *     "card_children_view"
 *   }
 * )
 */
class CardChildrenWidget extends WidgetBase {

    use CardWidgetTrait;

    /**
     * {@inheritdoc}
     */
    public function formElement(
        FieldItemListInterface $items,
        $delta,
        array $element,
        array &$form,
        FormStateInterface $form_state
    ) {

        $selected_view_modes = $this->getFieldSetting('view_modes');
        // Remove zero values.
        $selected_view_modes = array_filter($selected_view_modes);

        // Re-instate node. prefix.
        $selected_view_modes = preg_filter('/^/', 'node.', $selected_view_modes);

      $view_mode_classes = \Drupal::service('entity_type.manager')->getStorage('entity_view_mode')->load($selected_view_modes);

        $view_modes = [];
        foreach ($view_mode_classes as $id => $class) {
            $view_modes[$id] = $class->label();
        }


        $element['view_mode'] = [
            '#type' => 'select',
            '#title' => 'View Mode',
            '#title_display' => 'hidden',
            '#default_value' => isset($items[$delta]->view_mode) ? $items[$delta]->view_mode : '',
            '#options' => $view_modes,
        ];

        $element = $this->cardOptions($items, $delta, $element, $form, $form_state);




        return $element;
    }

}
