<?php


namespace Drupal\cards\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;

trait CardWidgetTrait {


    public function cardOptions(     $items,
                                    $delta,
                                     $element,
                                     &$form,
                                     $form_state) {

        $available_colors = $this->getFieldSetting('colors');
        $available_widths = $this->getFieldSetting('widths');
        $available_heights = $this->getFieldSetting('heights');
        $available_icons = $this->getFieldSetting('icons');
        $available_classes = $this->getFieldSetting('classes');

        $color = isset($items[$delta]->color) ? $items[$delta]->color : 'grey-light';
        if (count($available_colors)) {
            $element['color'] = [
                '#type' => 'select',
                '#title' => t('Color'),
                '#title_display' => 'hidden',
                '#default_value' => $color,
                '#options' => $available_colors,
            ];

        }
        else {
            // Hidden color field.
            $element['color'] = [
                '#type' => 'hidden',
                '#default_value' => '',
            ];
        }

        $width = isset($items[$delta]->width) ? $items[$delta]->width : '100';

        if (count($available_widths)) {

            // Width.
            $element['width'] = [
                '#type' => 'select',
                '#title' => t('Width'),
                '#title_display' => 'hidden',
                '#default_value' => $width,
                '#options' => $available_widths,
            ];

        }
        else {
            // Hidden width field.
            $element['width'] = [
                '#type' => 'hidden',
                '#default_value' => '',
            ];

        }

        $height = isset($items[$delta]->height) ? $items[$delta]->height : '100';

        if (count($available_heights)) {

            // Height.
            $element['height'] = [
                '#type' => 'select',
                '#title' => t('Height'),
                '#title_display' => 'hidden',
                '#default_value' => $height,
                '#options' => $available_heights,
            ];
        }
        else {

            // Hidden height field.
            $element['height'] = [
                '#type' => 'hidden',
                '#default_value' => '',
            ];
        }

        $icon = isset($items[$delta]->icon) ? $items[$delta]->icon : '100';

        if (count($available_icons)) {

            // Height.
            $element['icon'] = [
                '#type' => 'select',
                '#title' => t('Icon'),
                '#title_display' => 'hidden',
                '#default_value' => $icon,
                '#options' => $available_icons,
            ];
        }
        else {

            // Hidden icon field.
            $element['icon'] = [
                '#type' => 'hidden',
                '#default_value' => '',
            ];
        }

        $classes = isset($items[$delta]->classes) ? $items[$delta]->classes : [];
        $element['classes'] = [
            '#type' => 'checkboxes',
            '#title_display' => 'attribute',
            '#default_value' => $classes,
            '#options' => $available_classes,
            '#suffix' => '</div>',
        ];
        return $element;
    }
}

